==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/fi-FI.pl <==
{
  am_pm_abbreviated => [
    "ap.",
    "ip.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h.mm B",
    Bhms => "h.mm.ss B",
    E => "ccc",
    EBhm => "E h.mm B",
    EBhms => "E h.mm.ss B",
    EHm => "E H.mm",
    EHms => "E H.mm.ss",
    Ed => "E d.",
    Ehm => "E h.mm a",
    Ehms => "E h.mm.ss a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "H",
    Hm => "H.mm",
    Hms => "H.mm.ss",
    Hmsv => "H.mm.ss v",
    Hmv => "H.mm v",
    M => "L",
    MEd => "E d.M.",
    MMM => "LLL",
    MMMEd => "ccc d. MMM",
    "MMMMW-count-one" => "LLLL'n' W. 'viikko'",
    "MMMMW-count-other" => "LLLL'n' W. 'viikko'",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h.mm a",
    hms => "h.mm.ss a",
    hmsv => "h.mm.ss a v",
    hmv => "h.mm a v",
    ms => "m.ss",
    y => "y",
    yM => "L.y",
    yMEd => "E d.M.y",
    yMM => "M.y",
    yMMM => "LLL y",
    yMMMEd => "E d. MMM y",
    yMMMM => "LLLL y",
    yMMMMccccd => "cccc d. MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'vuoden' Y 'viikko' w",
    "yw-count-other" => "'vuoden' Y 'viikko' w",
  },
  code => "fi-FI",
  date_format_full => "cccc d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d.M.y",
  date_format_short => "d.M.y",
  datetime_format_full => "{1} 'klo' {0}",
  datetime_format_long => "{1} 'klo' {0}",
  datetime_format_medium => "{1} 'klo' {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "ma",
    "ti",
    "ke",
    "to",
    "pe",
    "la",
    "su",
  ],
  day_format_narrow => [
    "M",
    "T",
    "K",
    "T",
    "P",
    "L",
    "S",
  ],
  day_format_wide => [
    "maanantaina",
    "tiistaina",
    "keskiviikkona",
    "torstaina",
    "perjantaina",
    "lauantaina",
    "sunnuntaina",
  ],
  day_stand_alone_abbreviated => [
    "ma",
    "ti",
    "ke",
    "to",
    "pe",
    "la",
    "su",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "K",
    "T",
    "P",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "maanantai",
    "tiistai",
    "keskiviikko",
    "torstai",
    "perjantai",
    "lauantai",
    "sunnuntai",
  ],
  era_abbreviated => [
    "eKr.",
    "jKr.",
  ],
  era_narrow => [
    "eKr",
    "jKr",
  ],
  era_wide => [
    "ennen Kristuksen syntym\N{U+00e4}\N{U+00e4}",
    "j\N{U+00e4}lkeen Kristuksen syntym\N{U+00e4}n",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %-d.%-m.%Y %H.%M.%S %z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %e. %Bta %Y %H.%M.%S",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H.%M.%S",
  language => "Finnish",
  month_format_abbreviated => [
    "tammik.",
    "helmik.",
    "maalisk.",
    "huhtik.",
    "toukok.",
    "kes\N{U+00e4}k.",
    "hein\N{U+00e4}k.",
    "elok.",
    "syysk.",
    "lokak.",
    "marrask.",
    "jouluk.",
  ],
  month_format_narrow => [
    "T",
    "H",
    "M",
    "H",
    "T",
    "K",
    "H",
    "E",
    "S",
    "L",
    "M",
    "J",
  ],
  month_format_wide => [
    "tammikuuta",
    "helmikuuta",
    "maaliskuuta",
    "huhtikuuta",
    "toukokuuta",
    "kes\N{U+00e4}kuuta",
    "hein\N{U+00e4}kuuta",
    "elokuuta",
    "syyskuuta",
    "lokakuuta",
    "marraskuuta",
    "joulukuuta",
  ],
  month_stand_alone_abbreviated => [
    "tammi",
    "helmi",
    "maalis",
    "huhti",
    "touko",
    "kes\N{U+00e4}",
    "hein\N{U+00e4}",
    "elo",
    "syys",
    "loka",
    "marras",
    "joulu",
  ],
  month_stand_alone_narrow => [
    "T",
    "H",
    "M",
    "H",
    "T",
    "K",
    "H",
    "E",
    "S",
    "L",
    "M",
    "J",
  ],
  month_stand_alone_wide => [
    "tammikuu",
    "helmikuu",
    "maaliskuu",
    "huhtikuu",
    "toukokuu",
    "kes\N{U+00e4}kuu",
    "hein\N{U+00e4}kuu",
    "elokuu",
    "syyskuu",
    "lokakuu",
    "marraskuu",
    "joulukuu",
  ],
  name => "Finnish Finland",
  native_language => "suomi",
  native_name => "suomi Suomi",
  native_script => undef,
  native_territory => "Suomi",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. nelj.",
    "2. nelj.",
    "3. nelj.",
    "4. nelj.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. nelj\N{U+00e4}nnes",
    "2. nelj\N{U+00e4}nnes",
    "3. nelj\N{U+00e4}nnes",
    "4. nelj\N{U+00e4}nnes",
  ],
  quarter_stand_alone_abbreviated => [
    "1. nelj.",
    "2. nelj.",
    "3. nelj.",
    "4. nelj.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. nelj\N{U+00e4}nnes",
    "2. nelj\N{U+00e4}nnes",
    "3. nelj\N{U+00e4}nnes",
    "4. nelj\N{U+00e4}nnes",
  ],
  script => undef,
  territory => "Finland",
  time_format_full => "H.mm.ss zzzz",
  time_format_long => "H.mm.ss z",
  time_format_medium => "H.mm.ss",
  time_format_short => "H.mm",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/fi-FI.pl <==
{
  am_pm_abbreviated => [
    "ap.",
    "ip.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h.mm B",
    Bhms => "h.mm.ss B",
    E => "ccc",
    EBhm => "E h.mm B",
    EBhms => "E h.mm.ss B",
    EHm => "E H.mm",
    EHms => "E H.mm.ss",
    Ed => "E d.",
    Ehm => "E h.mm\N{U+202f}a",
    Ehms => "E h.mm.ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMMEd => "E d. MMMM y G",
    GyMMMMd => "d. MMMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "M.d.y G",
    H => "H",
    Hm => "H.mm",
    Hms => "H.mm.ss",
    Hmsv => "H.mm.ss v",
    Hmv => "H.mm v",
    M => "L",
    MEd => "E d.M.",
    MMM => "LLL",
    MMMEd => "ccc d. MMM",
    MMMMEd => "ccc d. MMMM",
    "MMMMW-count-one" => "LLLL'n' W. 'viikko'",
    "MMMMW-count-other" => "LLLL'n' W. 'viikko'",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "d.M.",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h.mm\N{U+202f}a",
    hms => "h.mm.ss\N{U+202f}a",
    hmsv => "h.mm.ss\N{U+202f}a v",
    hmv => "h.mm\N{U+202f}a v",
    ms => "m.ss",
    y => "y",
    yM => "L.y",
    yMEd => "E d.M.y",
    yMM => "M.y",
    yMMM => "LLL y",
    yMMMEd => "E d. MMM y",
    yMMMM => "LLLL y",
    yMMMMEd => "E d. MMMM y",
    yMMMMccccd => "cccc d. MMMM y",
    yMMMMd => "d. MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'vuoden' Y 'viikko' w",
    "yw-count-other" => "'vuoden' Y 'viikko' w",
  },
  code => "fi-FI",
  date_format_full => "cccc d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d.M.y",
  date_format_short => "d.M.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "ma",
    "ti",
    "ke",
    "to",
    "pe",
    "la",
    "su",
  ],
  day_format_narrow => [
    "M",
    "T",
    "K",
    "T",
    "P",
    "L",
    "S",
  ],
  day_format_wide => [
    "maanantaina",
    "tiistaina",
    "keskiviikkona",
    "torstaina",
    "perjantaina",
    "lauantaina",
    "sunnuntaina",
  ],
  day_stand_alone_abbreviated => [
    "ma",
    "ti",
    "ke",
    "to",
    "pe",
    "la",
    "su",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "K",
    "T",
    "P",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "maanantai",
    "tiistai",
    "keskiviikko",
    "torstai",
    "perjantai",
    "lauantai",
    "sunnuntai",
  ],
  era_abbreviated => [
    "eKr.",
    "jKr.",
  ],
  era_narrow => [
    "eKr",
    "jKr",
  ],
  era_wide => [
    "ennen Kristuksen syntym\N{U+00e4}\N{U+00e4}",
    "j\N{U+00e4}lkeen Kristuksen syntym\N{U+00e4}n",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %-d.%-m.%Y %H.%M.%S %z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %e. %Bta %Y %H.%M.%S",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H.%M.%S",
  language => "Finnish",
  month_format_abbreviated => [
    "tammik.",
    "helmik.",
    "maalisk.",
    "huhtik.",
    "toukok.",
    "kes\N{U+00e4}k.",
    "hein\N{U+00e4}k.",
    "elok.",
    "syysk.",
    "lokak.",
    "marrask.",
    "jouluk.",
  ],
  month_format_narrow => [
    "T",
    "H",
    "M",
    "H",
    "T",
    "K",
    "H",
    "E",
    "S",
    "L",
    "M",
    "J",
  ],
  month_format_wide => [
    "tammikuuta",
    "helmikuuta",
    "maaliskuuta",
    "huhtikuuta",
    "toukokuuta",
    "kes\N{U+00e4}kuuta",
    "hein\N{U+00e4}kuuta",
    "elokuuta",
    "syyskuuta",
    "lokakuuta",
    "marraskuuta",
    "joulukuuta",
  ],
  month_stand_alone_abbreviated => [
    "tammi",
    "helmi",
    "maalis",
    "huhti",
    "touko",
    "kes\N{U+00e4}",
    "hein\N{U+00e4}",
    "elo",
    "syys",
    "loka",
    "marras",
    "joulu",
  ],
  month_stand_alone_narrow => [
    "T",
    "H",
    "M",
    "H",
    "T",
    "K",
    "H",
    "E",
    "S",
    "L",
    "M",
    "J",
  ],
  month_stand_alone_wide => [
    "tammikuu",
    "helmikuu",
    "maaliskuu",
    "huhtikuu",
    "toukokuu",
    "kes\N{U+00e4}kuu",
    "hein\N{U+00e4}kuu",
    "elokuu",
    "syyskuu",
    "lokakuu",
    "marraskuu",
    "joulukuu",
  ],
  name => "Finnish Finland",
  native_language => "suomi",
  native_name => "suomi Suomi",
  native_script => undef,
  native_territory => "Suomi",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. nelj.",
    "2. nelj.",
    "3. nelj.",
    "4. nelj.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. nelj\N{U+00e4}nnes",
    "2. nelj\N{U+00e4}nnes",
    "3. nelj\N{U+00e4}nnes",
    "4. nelj\N{U+00e4}nnes",
  ],
  quarter_stand_alone_abbreviated => [
    "1. nelj.",
    "2. nelj.",
    "3. nelj.",
    "4. nelj.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. nelj\N{U+00e4}nnes",
    "2. nelj\N{U+00e4}nnes",
    "3. nelj\N{U+00e4}nnes",
    "4. nelj\N{U+00e4}nnes",
  ],
  script => undef,
  territory => "Finland",
  time_format_full => "H.mm.ss zzzz",
  time_format_long => "H.mm.ss z",
  time_format_medium => "H.mm.ss",
  time_format_short => "H.mm",
  variant => undef,
  version => 42,
}
